@@ -1,5 +1,5 @@
 #!/bin/bash
-perldoc -oHTML -ddocs/apiconnector.html WebService::Hexonet::Connector
+perldoc -oHTML -ddocs/connector.html WebService::Hexonet::Connector
 perldoc -oHTML -ddocs/hexonet.html WebService::Hexonet
 perldoc -oHTML -ddocs/util.html WebService::Hexonet::Connector::Util
 perldoc -oHTML -ddocs/connection.html WebService::Hexonet::Connector::Connection
